@@ -3,7 +3,7 @@ import numpy as np
 def areSNPsIncluded( snps, n_snps, fname ):
     for snp in snps:
         if snp >= n_snps:
-            print 'Cannot read dosages for ' + str( snp ) + 'th SNP. File "' + fname + '" contains only ' + str( n_snps ) + ' SNPs!'
+            print( 'Cannot read dosages for ' + str( snp ) + 'th SNP. File "' + fname + '" contains only ' + str( n_snps ) + ' SNPs!' )
             return
 
 def convertIntToFloat( x, n_bytes ):
@@ -36,5 +36,5 @@ def getIntNA( n_bytes ):
     elif n_bytes == 1:
         return 208
     else:
-        print 'Only 1, 2, 4 and 8 bytes are supported!'
+        print( 'Only 1, 2, 4 and 8 bytes are supported!' )
         return
